// SPDX-FileCopyrightText: Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
// SPDX-License-Identifier: BSD-3-Clause

#include "vtkCutCell3D.h"

#include "vtkDataSetMapper.h"
#include "vtkNew.h"
#include "vtkPolyDataNormals.h"
#include "vtkProperty.h"
//#include "vtkRegressionTestImage.h"
#include "vtkRenderWindow.h"
#include "vtkRenderWindowInteractor.h"
#include "vtkRenderer.h"
#include "vtkSuperquadricSource.h"

#include "vtkXMLUnstructuredGridWriter.h"

//int TestCutCell3D(int vtkNotUsed(argc), char* vtkNotUsed(argv)[])
int main(int argc, char* argv[])
{
  vtkNew<vtkSuperquadricSource> superquadricSource;
  superquadricSource->SetThetaResolution(20);
  superquadricSource->SetPhiResolution(20);
  superquadricSource->SetThetaRoundness(1.0);
  superquadricSource->SetPhiRoundness(1.0);
  superquadricSource->SetYAxisOfSymmetry();
  superquadricSource->ToroidalOn();

  vtkNew<vtkCutCell3D> cutCell;
  cutCell->SetInputConnection(superquadricSource->GetOutputPort());
  cutCell->SetGridDimensions(10, 10, 10);
  cutCell->InsideOutOn();
  cutCell->ComputeVolumeOn();
  cutCell->SetShrink(0);
  cutCell->Update();

  vtkNew<vtkXMLUnstructuredGridWriter> writer;
  writer->SetFileName("cutcell.vtu");
  writer->SetInputConnection(cutCell->GetOutputPort());
  writer->Write();

  //vtkNew<vtkDataSetMapper> cutCellMapper;
  //cutCellMapper->SetInputConnection(cutCell->GetOutputPort());
  //cutCellMapper->SetScalarModeToUseCellData();
  //cutCellMapper->SetScalarRange(1.0, 2.0);
  //cutCellMapper->InterpolateScalarsBeforeMappingOn();
  //vtkNew<vtkActor> cutCellActor;
  //cutCellActor->SetMapper(cutCellMapper);

  //// drawing
  //vtkNew<vtkRenderer> ren;
  //ren->SetBackground(1, 1, 1);
  //ren->AddActor(cutCellActor);
  //vtkNew<vtkRenderWindow> renWin;
  //renWin->AddRenderer(ren);
  //renWin->SetSize(600, 600);
  //renWin->SetMultiSamples(0);
  //vtkNew<vtkRenderWindowInteractor> iren;
  //iren->SetRenderWindow(renWin);

  //ren->ResetCamera();
  //renWin->Render();

  //int retVal = vtkRegressionTestImage(renWin);
  //if (retVal == vtkRegressionTester::DO_INTERACTOR)
  //{
  //  iren->Start();
  //  retVal = vtkRegressionTester::PASSED;
  //}

  //return (retVal == vtkRegressionTester::PASSED) ? EXIT_SUCCESS : EXIT_FAILURE;

  return EXIT_SUCCESS;
}
